@@ -47,7 +47,7 @@
 #define MAX_EVENTS 4
 
 // External variables
-extern volatile atomic_bool stop, run_stats;
+extern atomic_bool stop, run_stats;
 extern unsigned int permissive;
 
 // Local variables
@@ -59,8 +59,8 @@ static pthread_mutexattr_t decision_lock_attr;
 static pthread_mutex_t decision_lock;
 static pthread_cond_t do_decision;
 static pthread_condattr_t rpt_timer_attr;
-static volatile atomic_bool events_ready;
-static volatile atomic_int alive = 1;
+static atomic_bool events_ready;
+static atomic_int alive = 1;
 static int fd = -1;
 static int rpt_timer_fd = -1;
 static uint64_t mask;
@@ -414,14 +414,17 @@ static void *decision_thread_main(void *arg)
 				pthread_cond_timedwait(&do_decision,
 						       &decision_lock,
 						       &rpt_timeout);
-			} else if (run_stats) {
-				rpt_write();
-				run_stats = 0;
+			} else {
+				if (run_stats) {
+					rpt_write();
+					run_stats = 0;
+				}
+				if (stop)
+					break;
+
+				// no interval reports, await a fan event indefinitely
+				pthread_cond_wait(&do_decision, &decision_lock);
 			}
-			// no interval reports, await a fan event indefinitely
-			if (stop)
-				break;
-			pthread_cond_wait(&do_decision, &decision_lock);
 		}
 
 		if (stop) {
