@@ -106,6 +106,9 @@ static Queue *create_queue(unsigned int qsize, const char *name)
 
 	queue->name = name;
 
+	queue->cleanup = NULL;
+	queue->evict_cb = NULL;
+
 	return queue;
 }
 
@@ -257,6 +260,9 @@ static void dequeue(Queue *queue)
 	QNode *temp = queue->end;
 	remove_node(queue, queue->end);
 
+	// Let caller know an entry is being evicted
+	if (queue->evict_cb)
+		queue->evict_cb(temp->item);
 	queue->cleanup(temp->item);
 	free(temp->item);
 	free(temp);
@@ -265,22 +271,47 @@ static void dequeue(Queue *queue)
 	queue->count--;
 }
 
-// Remove front of the queue because its a mismatch
+/*
+ * lru_evict - remove the cache entry that should be at the front of the
+ *             queue
+ * @queue: pointer to the LRU queue
+ * @key:   hash index for the entry to evict
+ *
+ * The caller must first move the desired entry to the front of the queue by
+ * calling check_lru_cache() with the same key. This ensures that @key refers
+ * to the front node. If the node at the front does not match @key, the
+ * program will abort as this is a usage error.
+ */
 void lru_evict(Queue *queue, unsigned int key)
 {
 	if (queue_is_empty(queue))
 		return;
 
+	if (key >= queue->total) {
+		msg(LOG_ERR, "lru_evict called with out of bounds key");
+		return;
+	}
+
 	Hash *hash = queue->hash;
 	QNode *temp = queue->front;
+
+	if (hash->array[key] != temp) {
+		msg(LOG_ERR, "lru_evict called with mismatched key %s",
+			queue->name);
+		abort();
+	}
+
 	hash->array[key] = NULL;
 	remove_node(queue, queue->front);
 
+	// Let caller know an entry is being evicted
+	if (queue->evict_cb)
+		queue->evict_cb(temp->item);
 	queue->cleanup(temp->item);
 	free(temp->item);
 	free(temp);
 
-        // decrement the total of full slots by 1
+	// decrement the total of full slots by 1
 	queue->count--;
 	queue->evictions++;
 }
@@ -348,13 +379,14 @@ QNode *check_lru_cache(Queue *queue, unsigned int key)
 }
 
 Queue *init_lru(unsigned int qsize, void (*cleanup)(void *),
-		const char *name)
+		const char *name, void (*evict_cb)(void *))
 {
 	Queue *q = create_queue(qsize, name);
 	if (q == NULL)
 		return q;
 
 	q->cleanup = cleanup;
+	q->evict_cb = evict_cb;
 	q->hash = create_hash(qsize);
 
 	return q;
