@@ -55,8 +55,8 @@ static unsigned long allowed = 0, denied = 0;
 static nvlist_t fields[MAX_SYSLOG_FIELDS];
 static unsigned int num_fields;
 
-extern volatile atomic_bool stop;
-volatile atomic_bool reload_rules = false;
+extern atomic_bool stop;
+atomic_bool reload_rules = false;
 
 static const nv_t table[] = {
 {       NO_OPINION, "no-opinion" },
@@ -389,19 +389,23 @@ static char *format_value(int item, unsigned int num, decision_t results,
 		object_attr_t *obj = get_obj_attr(e, item);
 		if (item != OBJ_TRUST) {
 			char * str = obj ? obj->o : "?";
+			char *tmp = NULL;
 			size_t need_escape = check_escape_shell(str);
 
-			if (need_escape)
+			if (need_escape) {
 				// need_escape contains potential size of escaped string
-				str = escape_shell(str, need_escape);
+				tmp = escape_shell(str, need_escape);
+				str = tmp;
+			}
 
-			if (asprintf(&out, "%s", str ? str : "??") < 0)
+			if (asprintf(&out, "%s", str ? str : "??") < 0) {
 				out = NULL;
-
-		} else {
+				free(tmp);
+			}
+			free(tmp);
+		} else
 		    if (asprintf(&out, "%d", obj ? (obj->val ? 1 : 0) : 9) < 0)
 				out = NULL;
-		}
 	} else {
 		subject_attr_t *subj = get_subj_attr(e, item);
 		if (item < GID) {
@@ -409,14 +413,18 @@ static char *format_value(int item, unsigned int num, decision_t results,
 				out = NULL;
 		} else if (item >= COMM) {
 			char * str = subj ? subj->str : "?";
+			char *tmp = NULL;
 			size_t need_escape = check_escape_shell(str);
 
-			if (need_escape)
+			if (need_escape) {
 				// need_escape contains potential size of escaped string
-				str = escape_shell(str, need_escape);
+				tmp = escape_shell(str, need_escape);
+				str = tmp;
+			}
 
 			if (asprintf(&out, "%s", str ? str : "??") < 0)
 				out = NULL;
+			free(tmp);
 
 		} else { // GID only log first 32
 			out = malloc(NGID_LIMIT*12);
@@ -562,15 +570,10 @@ static int test_info_api(int fd)
 }
 #endif
 
-#ifdef USE_RPM
-int push_fd_to_buffer(int);
-extern volatile atomic_bool ongoing_rpm_operation;
-extern const char *rpm_dir_path;
-extern ssize_t rpm_dir_path_len;
-#endif
 void reply_event(int fd, const struct fanotify_event_metadata *metadata,
 		unsigned reply, event_t *e)
 {
+	close(metadata->fd);
 #ifdef FAN_AUDIT_RULE_NUM
 	static int use_new = 2;
 	if (use_new == 2)
@@ -609,24 +612,6 @@ void reply_event(int fd, const struct fanotify_event_metadata *metadata,
 	response.fd = metadata->fd;
 	response.response = reply;
 	write(fd, &response, sizeof(struct fanotify_response));
-
-#ifdef USE_RPM
-	if (ongoing_rpm_operation) {
-
-		object_attr_t *obj;
-		char *path = NULL;
-		if (e && (obj = get_obj_attr(e, PATH))) {
-			path = obj->o;
-		}
-
-		if (path && !strncmp(path, rpm_dir_path, rpm_dir_path_len)) {
-			if(push_fd_to_buffer(metadata->fd))
-				close(metadata->fd);
-			return; // no close for now
-		}
-	}
-#endif
-	close(metadata->fd);
 }
 
 
