@@ -124,27 +124,14 @@ static int get_next_file_rpm(void)
 			fi = NULL;
 			return 0;
 		}
-        }
+	}
 	return 1;
 }
 
-// Like strdup, but sets a minimum size for safety
-static inline char *strmdup(const char *s, size_t min) __attr_dealloc_free;
-static inline char *strmdup(const char *s, size_t min)
-{
-	char *new;
-	size_t len = strlen(s) + 1;
-
-	new = malloc(len < min ? min : len);
-	if (new == NULL)
-		return NULL;
-
-	return (char *)memcpy(new, s, len);
-}
-
 static const char *get_file_name_rpm(void)
-{
-	return strmdup(rpmfiFN(fi), 7);
+{	// Copy is made because the linked list takes custody of it
+	// FIXME: if the linked list ever goes away, remove strdup
+	return strdup(rpmfiFN(fi));
 }
 
 static rpm_loff_t get_file_size_rpm(void)
@@ -225,7 +212,7 @@ struct _hash_record {
 static int rpm_load_list(const conf_t *conf)
 {
 
-// before the spawn
+	// before the spawn
 	int sv[2];
 	if (socketpair(AF_UNIX, SOCK_SEQPACKET, 0, sv) < 0) {
 		msg(LOG_ERR, "socketpair failed");
@@ -244,16 +231,20 @@ static int rpm_load_list(const conf_t *conf)
 	char *custom_env[] = { "FAPO_SOCK_FD=3", NULL };
 
 	pid_t pid = -1;
-	int status = posix_spawn(&pid, "/usr/sbin/fapolicyd-rpm-loader",
-							 &actions, NULL, argv, custom_env);
+	int status = posix_spawn(&pid, "/usr/bin/fapolicyd-rpm-loader",
+					 &actions, NULL, argv, custom_env);
 	close(sv[1]);  // Parent doesn't write
 
 	if (status == 0) {
-		msg(LOG_DEBUG, "fapolicyd-rpm-loader spawned with pid: %d", pid);
+		msg(LOG_DEBUG, "fapolicyd-rpm-loader spawned with pid: %d",pid);
 
 		struct msghdr  _msg  = {0};
-		struct iovec   iov  = { .iov_base = (char[1]){0}, .iov_len = 1 };
-		union { struct cmsghdr align; char buf[CMSG_SPACE(sizeof(int))]; } cmsgbuf;
+		struct iovec   iov = { .iov_base = (char[1]){0}, .iov_len = 1 };
+		union {
+			struct cmsghdr align;
+			char buf[CMSG_SPACE(sizeof(int))];
+		} cmsgbuf;
+
 		_msg.msg_iov    = &iov;
 		_msg.msg_iovlen = 1;
 		_msg.msg_control = cmsgbuf.buf;
@@ -292,13 +283,12 @@ static int rpm_load_list(const conf_t *conf)
 			if (res == -1) {
 				msg(LOG_ERR, "fd_fgets_r on memfd");
 				break;
-			}
-			else if (res > 0) {
-				char* end  = strchr(buff, '\n');
+			} else if (res > 0) {
+				char *end  = strchr(buff, '\n');
 
 				if (end == NULL) {
 					msg(LOG_ERR, "Too long line?");
-						continue;
+					continue;
 				}
 
 				int size = end - buff;
@@ -307,7 +297,7 @@ static int rpm_load_list(const conf_t *conf)
 				// its better to parse it from the end because
 				// there can be space in file name
 				int delims = 0;
-				char * delim = NULL;
+				char *delim = NULL;
 				for (int i = size-1 ; i >= 0 ; i--) {
 					if (isspace(buff[i])) {
 						delim = &buff[i];
@@ -331,7 +321,8 @@ static int rpm_load_list(const conf_t *conf)
 			}
 		} while(!fd_fgets_eof_r(st));
 
-		fd_fgets_destroy(st);
+		fd_fgets_destroy(st); // calls munmap
+		close(memfd);
 		waitpid(pid, NULL, 0);
 	} else {
 		msg(LOG_ERR, "posix_spawn failed: %s\n", strerror(status));
@@ -387,20 +378,23 @@ int do_rpm_load_list(const conf_t *conf)
 
 			// Get specific file information
 			const char *file_name = get_file_name_rpm();
-			rpm_loff_t sz = get_file_size_rpm();
-			int len;
-			const char *sha = get_sha256_rpm(&len);
-			char *data;
-
 			if (file_name == NULL)
 				continue;
 
 			// should we drop a path?
-			if (!filter_check(file_name)) {
+			filter_rc_t f_res = filter_check(file_name);
+			if (f_res != FILTER_ALLOW) {
 				free((void *)file_name);
+				if (f_res == FILTER_ERR_DEPTH)
+					return FILTER_ERR_DEPTH;
 				continue;
 			}
 
+			rpm_loff_t sz = get_file_size_rpm();
+			int len;
+			const char *sha = get_sha256_rpm(&len);
+			char *data;
+
 			// Note that some rpm builders have moved to
 			// SHA512. Originally this was to weed out SHA1.
 			// FIXME: This should be revisited to allow SHA512.
@@ -483,7 +477,7 @@ int do_rpm_init_backend(void)
 	if (filter_init())
 		return 1;
 
-	if (filter_load_file()) {
+	if (filter_load_file(NULL)) {
 		filter_destroy();
 		return 1;
 	}
